===========
GFW Creator
===========


.. image:: https://img.shields.io/pypi/v/gfw_creator.svg
        :target: https://pypi.python.org/pypi/gfw_creator

.. image:: https://img.shields.io/travis/pgierz/gfw_creator.svg
        :target: https://travis-ci.org/pgierz/gfw_creator

.. image:: https://readthedocs.org/projects/gfw-creator/badge/?version=latest
        :target: https://gfw-creator.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




GFW Creator allows you to generate files for the gfw_atmo switch in ECHAM6/JSBACH of AWI-ESM


* Free software: GNU General Public License v3
* Documentation: https://gfw-creator.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
